<?php

namespace App\Providers;

use App\Models\Authorization\Authorization;
use App\Models\Authorization\KeyAuthorization;
use App\Models\Authorization\TokenAuthorization;
use Illuminate\Support\ServiceProvider;
use Request;
use Cookie;

class AuthorizationServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     *
     * @return void
     */
    public function register()
    {
        $key = $this->parseKey();
        // Check if Authorization is done through Token or through Key
        $tokens = Request::header(("tokens"));
        $tokenauthorization = null;
        if ($tokens === null) {
            $tokens = Cookie::get("tokens");
        }
        if (Request::hasHeader("tokenauthorization")) {
            $tokenauthorization = Request::header("tokenauthorization");
        } else if (Cookie::has("tokenauthorization")) {
            $tokenauthorization = Cookie::get("tokenauthorization");
        }
        if ($key === "" && ($tokens !== null || $tokenauthorization !== null)) {
            $this->app->singleton(Authorization::class, function ($app) use ($tokens, $tokenauthorization) {
                return new TokenAuthorization(tokenString: $tokens, tokenauthorization: $tokenauthorization);
            });
        } else {
            $this->app->singleton(Authorization::class, function ($app) use ($key) {
                return new KeyAuthorization($key);
            });
        }
    }

    private function parseKey(): string
    {
        $key = "";
        if (Cookie::has('key')) {
            $key = Cookie::get('key');
        }
        if (Request::hasHeader("key")) {
            $key = Request::header("key");
        }
        if (Request::filled('key')) {
            $key = Request::input('key');
        }
        return $key;
    }



    /**
     * Bootstrap services.
     *
     * @return void
     */
    public function boot()
    {
        //
    }
}